Verifies stop criteria for the MOEADr package.
check_stop_criteria(stopcrit, call.env)list containing the parameters defining the stop
handling method. See Section Stop Criteria of the moead()
documentation for details.
List vector containing the stop criteria to be used.
See moead() for details.
Flag keep.running, indicating whether the algorithm should continue
(TRUE) or terminate (FALSE).
This routine is intended to be used internally by moead(),
and should not be called directly by the user.
F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A Component-Based Framework for Multiobjective Evolutionary Algorithms Based on Decomposition. Journal of Statistical Software 10.18637/jss.v092.i06