Learn R Programming

MOEADr (version 1.1.1)

create_population: Create population

Description

Create a population for the MOEADr package

Usage

create_population(N, problem)

Arguments

N

population size

problem

list of named problem parameters. See Section Problem Description of the moead() documentation for details.

Value

A population matrix X for the MOEA/D.

Details

This routine creates a population matrix for the MOEA/D. Currently only a multivariate uniform distribution is implemented. All points are created within the standardized space \(0 \le x_i \le 1, i = 1,...,n_v\).

References

F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A Component-Based Framework for Multiobjective Evolutionary Algorithms Based on Decomposition. Journal of Statistical Software 10.18637/jss.v092.i06

Examples

Run this code
# NOT RUN {
ex.problem <- list(name = "example_problem",
                   xmin = rep(-1, 5),
                   xmax = rep(1, 5),
                   m    = 2)
X <- create_population(20, ex.problem)

# }

Run the code above in your browser using DataLab