List containing the decomposition method parameters. See
moead() for details.
m
Number of objectives (\(m \ge 2\))
...
other parameters (included for compatibility with generic call)
Details
This routine calculates the weight vectors for the MOEA/D. The
list of available methods for generating the weights, as well as information
about their specific parameters, can be generated using
get_decomposition_methods().
References
F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A
Component-Based Framework for Multiobjective Evolutionary Algorithms Based on
Decomposition. Journal of Statistical Software tools:::Rd_expr_doi("10.18637/jss.v092.i06")