Learn R Programming

MOEADr (version 1.1.3)

get_scalarization_methods: Print available scalarization methods

Description

Prints the scalarization methods available in the MOEADr package

Usage

get_scalarization_methods()

Arguments

Value

Formatted data frame containing reference name (for aggfun$name) and instructions for More Info about each method.

Details

This routine prints the names of the scalarization methods available in the MOEADr package, to be used as the aggfun$name parameter in the moead(...) call. Instructions for obtaining more info on each operator are also returned.

Examples

Run this code
get_scalarization_methods()

Run the code above in your browser using DataLab