Sequentially apply variation operators for the MOEADr package
perform_variation(variation, X, iter, ...)List object containing a modified population matrix X, a
local search argument list ls.arg, and the number of function evaluations
used by the variation operators, var.nfe.
List vector containing the variation operators to be used.
See moead() for details.
Population matrix of the MOEA/D (each row is a candidate solution).
iterations counter of the moead() function.
other parameters to be passed down to the individual variation
operators (see documentation of the specific variation_xyz()
functions for details)
This routine performs the variation block for the MOEA/D. The
list of available variation operators can be generated using
get_variation_operators().
If the localsearch operator is included, it is executed whenever its
conditions (period of occurrence or probability of occurrence) are verified.
See variation_localsearch() for details.
F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A
Component-Based Framework for Multiobjective Evolutionary Algorithms Based on
Decomposition. Journal of Statistical Software tools:::Rd_expr_doi("10.18637/jss.v092.i06")