Learn R Programming

MOEADr (version 1.1.3)

scalarization_ipbi: Inverted Penalty-based Boundary Intersection Scalarization

Description

Perform inverted PBI Scalarization for the MOEADr package.

Usage

scalarization_ipbi(Y, W, maxP, aggfun, eps = 1e-16, ...)

Value

Vector of scalarized performance values.

Arguments

Y

matrix of objective function values

W

matrix of weights.

maxP

numeric vector containing estimated ideal point

aggfun

list containing parameters for the aggregation function. Must contain the non-negative numeric constant aggfun$theta.

eps

tolerance value for avoiding divisions by zero.

...

other parameters (included for compatibility with generic call)

Details

This routine calculates the scalarized performance values for the MOEA/D using the inverted PBI method.

References

H. Sato, "Inverted PBI in MOEA/D and its impact on the search performance on multi and many-objective optimization." Proceedings of the 2014 Annual Conference on Genetic and Evolutionary Computation (GECCO), 2014.

H. Sato, "Analysis of inverted PBI and comparison with other scalarizing functions in decomposition based MOEAs." Journal of Heuristics 21(6):819-849, 2015

F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A Component-Based Framework for Multiobjective Evolutionary Algorithms Based on Decomposition. Journal of Statistical Software tools:::Rd_expr_doi("10.18637/jss.v092.i06")

Examples

Run this code
W      <- generate_weights(decomp = list(name = "sld", H = 19), m = 2)
Y      <- matrix(runif(40), ncol = 2)
minP   <- apply(Y, 2, min)
aggfun <- aggfun    <- list(name = "ipbi", theta = 5)
Z      <- scalarization_ipbi(Y, W, minP, aggfun)

Run the code above in your browser using DataLab