Learn R Programming

MOEADr (version 1.1.1)

scalarization_pbi: Penalty-based Boundary Intersection Scalarization

Description

Perform PBI Scalarization for the MOEADr package.

Usage

scalarization_pbi(Y, W, minP, aggfun, eps = 1e-16, ...)

Arguments

Y

matrix of objective function values

W

matrix of weights.

minP

numeric vector containing estimated ideal point

aggfun

list containing parameters for the aggregation function. Must contain the non-negative numeric constant aggfun$theta.

eps

tolerance value for avoiding divisions by zero.

...

other parameters (included for compatibility with generic call)

Value

Vector of scalarized performance values.

Details

This routine calculates the scalarized performance values for the MOEA/D using the PBI method.

References

Q. Zhang and H. Li, "MOEA/D: A Multiobjective Evolutionary Algorithm Based on Decomposition", IEEE Trans. Evol. Comp. 11(6): 712-731, 2007.

H. Li, Q. Zhang, "Multiobjective Optimization Problems With Complicated Pareto Sets, MOEA/D and NSGA-II", IEEE. Trans. Evol. Comp. 12(2):284-302, 2009.

F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A Component-Based Framework for Multiobjective Evolutionary Algorithms Based on Decomposition. Journal of Statistical Software 10.18637/jss.v092.i06

Examples

Run this code
# NOT RUN {
W      <- generate_weights(decomp = list(name = "sld", H = 19), m = 2)
Y      <- matrix(runif(40), ncol = 2)
minP   <- apply(Y, 2, min)
aggfun <- aggfun    <- list(name = "pbi", theta = 5)
Z      <- scalarization_pbi(Y, W, minP, aggfun)

# }

Run the code above in your browser using DataLab