SBX implementation for the MOEA/D
variation_sbx(X, P, etax, pc = 1, eps = 1e-06, ...)Population matrix
Matrix of probabilities of selection for variation (created by
define_neighborhood()).
spread constant
variable-wise probability of recombination
smallest difference considered for recombination
other parameters (included for compatibility with generic call)
Matrix X' containing the recombined population
This R implementation of the Simulated Binary Crossover reproduces the C code implementation available in the R package emoa 0.5-0, by Olaf Mersmann. The differences between the present version and the original one are:
The operator is performed on the variables scaled to the [0, 1]
interval, which simplifies the calculations.
Calculations are vectorized over variables, which also simplifies the implementation.
Deb, K. and Agrawal, R. B. (1995) Simulated binary crossover for continuous search space. Complex Systems, 9 115-148
F. Campelo, L.S. Batista, C. Aranha (2020): The MOEADr Package: A Component-Based Framework for Multiobjective Evolutionary Algorithms Based on Decomposition. Journal of Statistical Software 10.18637/jss.v092.i06
Olaf Mersmann (2012). emoa: Evolutionary Multiobjective Optimization Algorithms. R package version 0.5-0. http://CRAN.R-project.org/package=emoa