get_constraint_methods: Print available constraint methods
Description
Prints the constraint handling methods available in the MOEADr package
Usage
get_constraint_methods()
Arguments
Value
Formatted data frame containing reference name (for
constraint$name) and instructions for More Info about each method.
Details
This routine prints the names of the constraint handling methods available in
the MOEADr package, to be used as the constraint$name parameter in the
moead(...) call. Instructions for obtaining more info on each
operator are also returned.